@@ -3,9 +3,9 @@ package GFX::Enhancer::PNGRGBA;
 ### endianess !
 
 sub new {
-	my ($class, $4bytes) = @_; ### $4bytes is a number
+	my ($class, $index, $4bytes) = @_; ### $4bytes is a number
 
-	my $self = { rgba => $4bytes, };
+	my $self = { index => $index, rgba => $4bytes, };
 
 	$class = ref($class) || $class;
 
@@ -14,7 +14,7 @@ sub new {
 
 ### public methods
 
-sub higher_colour_than_this {
+sub higher_colour {
 	my ($self, $rgba2) = @_;
 
 	if ($rgba2->{rgba} > $self->{rgba}) {
