@@ -7,6 +7,8 @@ sub new {
         $self->{filename} = "";
         $self->{bytes} = 0; ### number which stores all bytes of the png image
         $self->{length} = 0;
+	$self->{width} = 0;
+	$self->{height} = 0;
 }
 
 ### public methods
@@ -17,6 +19,8 @@ sub read_in_byte_array {
 
 	### FIXME png reader code
 	$self->{length} = ;
+	$self->{width} = ;
+	$self->{height} = ;
 }
 
 sub get_byte {
